Learn R Programming

mlr3verse (version 0.3.1)

mlr3verse-package: mlr3verse: Easily Install and Load the 'mlr3' Package Family

Description

The 'mlr3' package family is a set of packages for machine-learning purposes built in a modular fashion. This wrapper package is aimed to simplify the installation and loading of the core 'mlr3' packages. Get more information about the 'mlr3' project at https://mlr3book.mlr-org.com/.

Arguments

Author

Maintainer: Marc Becker marcbecker@posteo.de (ORCID)

Authors:

See Also