Learn R Programming

mlr3verse (version 0.3.1)

mlr3verse_info: Print mlr3* package versions

Description

Returns the package versions of imported and suggested mlr3 packages as a data.table::data.table(). Suggested packages that are not installed are listed with version NA.

Usage

mlr3verse_info()

Arguments

Examples

Run this code
mlr3verse_info()

Run the code above in your browser using DataLab