powered by
Returns the package versions of imported and suggested mlr3 packages as a data.table::data.table(). Suggested packages that are not installed are listed with version NA.
data.table::data.table()
NA
mlr3verse_info()
Run the code above in your browser using DataLab